@@ -7,7 +7,7 @@ Database::Abstraction - read-only database abstraction layer
 =cut
 
 # Author Nigel Horne: njh@bandsman.co.uk
-# Copyright (C) 2015-2024, Nigel Horne
+# Copyright (C) 2015-2025, Nigel Horne
 
 # Usage is subject to licence terms.
 # The licence terms of this software are as follows:
@@ -45,11 +45,11 @@ use constant	DEFAULT_MAX_SLURP_SIZE => 16 * 1024;	# CSV files <= than this size
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 SYNOPSIS
 
@@ -58,10 +58,26 @@ using caching for performance optimization.
 It offers functionalities like opening the database and fetching data based on various criteria,
 
 Look for databases in $directory in this order:
-1) SQLite (file ends with .sql)
-2) PSV (pipe separated file, file ends with .psv)
-3) CSV (file ends with .csv or .db, can be gzipped) (note the default sep_char is '!' not ',')
-4) XML (file ends with .xml)
+
+=over 4
+
+=item 1 C<SQLite>
+
+File ends with .sql
+
+=item 2 C<PSV>
+
+Pipe separated file, file ends with .psv
+
+=item 3 C<CSV>
+
+File ends with .csv or .db, can be gzipped. Note the default sep_char is '!' not ','
+
+=item 4 C<XML>
+
+File ends with .xml
+
+=back
 
 The AUTOLOAD feature allows for convenient access to database columns using method calls.
 
@@ -123,10 +139,11 @@ sub init
 	if(scalar(@_)) {
 		my %args = (ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
 
-		# $defaults->{'directory'} ||= $args{'directory'};
-		# $defaults->{'logger'} ||= $args{'logger'};
+		# $defaults->{'dbname'} ||= $args{'dbname'};
 		# $defaults->{'cache'} ||= $args{'cache'};
 		# $defaults->{'cache_duration'} ||= $args{'cache_duration'};
+		# $defaults->{'directory'} ||= $args{'directory'};
+		# $defaults->{'logger'} ||= $args{'logger'};
 		%defaults = (%defaults, %args)
 	}
 
@@ -141,10 +158,32 @@ Arguments:
 
 Takes different argument formats (hash or positional)
 
-cache => place to store results;
-cache_duration => how long to store results in the cache (default is 1 hour);
-directory => where the database file is held
-max_slurp_size => CSV/PSV/XML files smaller than this are held in RAM (default is 16K)
+=over 4
+
+=item * C<cache>
+
+Place to store results
+
+=item * C<cache_duration>
+
+How long to store results in the cache (default is 1 hour)
+
+=item * C<dbname>
+
+The prefix of name of the database file (default is name of the table).
+The database will be held in a file such as $dbname.csv.
+
+=item * C<directory>
+
+Where the database file is held
+
+=item * C<max_slurp_size>
+
+CSV/PSV/XML files smaller than this are held in RAM (default is 16K).
+Setting this value to 0 will turn this feature off,
+thus forcing SQL to be used to access the database
+
+=back
 
 If the arguments are not set, tries to take from class level defaults.
 
@@ -202,7 +241,6 @@ sub new {
 		# no_entry => $args{'no_entry'} || 0,
 	# }, $class;
 
-
 	# Re-seen keys take precedence, so defaults come first
 	return bless {
 		no_entry => 0,
@@ -254,7 +292,8 @@ sub _open {
 	my $dbh;
 
 	my $dir = $self->{'directory'} || $defaults{'directory'};
-	my $slurp_file = File::Spec->catfile($dir, "$table.sql");
+	my $dbname = $self->{'dbname'} || $defaults{'dbname'} || $table;
+	my $slurp_file = File::Spec->catfile($dir, "$dbname.sql");
 
 	$self->_debug("_open: try to open $slurp_file");
 
@@ -272,7 +311,7 @@ sub _open {
 		$self->{'type'} = 'DBI';
 	} else {
 		my $fin;
-		($fin, $slurp_file) = File::pfopen::pfopen($dir, $table, 'csv.gz:db.gz', '<');
+		($fin, $slurp_file) = File::pfopen::pfopen($dir, $dbname, 'csv.gz:db.gz', '<');
 		if(defined($slurp_file) && (-r $slurp_file)) {
 			require Gzip::Faster;
 			Gzip::Faster->import();
@@ -283,12 +322,12 @@ sub _open {
 			$slurp_file = $fin->filename();
 			$self->{'temp'} = $slurp_file;
 		} else {
-			($fin, $slurp_file) = File::pfopen::pfopen($dir, $table, 'psv', '<');
+			($fin, $slurp_file) = File::pfopen::pfopen($dir, $dbname, 'psv', '<');
 			if(defined($fin)) {
 				# Pipe separated file
 				$args{'sep_char'} = '|';
 			} else {
-				($fin, $slurp_file) = File::pfopen::pfopen($dir, $table, 'csv:db', '<');
+				($fin, $slurp_file) = File::pfopen::pfopen($dir, $dbname, 'csv:db', '<');
 			}
 		}
 		if(defined($slurp_file) && (-r $slurp_file)) {
@@ -400,13 +439,13 @@ sub _open {
 			}
 			$self->{'type'} = 'CSV';
 		} else {
-			$slurp_file = File::Spec->catfile($dir, "$table.xml");
+			$slurp_file = File::Spec->catfile($dir, "$dbname.xml");
 			if(-r $slurp_file) {
 				if((-s $slurp_file) <= $self->{'max_slurp_size'}) {
 					require XML::Simple;
 					XML::Simple->import();
 
-					my $xml = XMLin(File::Spec->catfile($dir, "$table.xml"));
+					my $xml = XMLin($slurp_file);
 					my @keys = keys %{$xml};
 					my $key = $keys[0];
 					my @data;
@@ -436,7 +475,7 @@ sub _open {
 				}
 			} else {
 				# throw Error(-file => "$dir/$table");
-				croak("Can't find a $table database in $dir");
+				Carp::croak("Can't find a $dbname file for the table $table in $dir");
 			}
 			$self->{'type'} = 'XML';
 		}
@@ -1023,12 +1062,12 @@ so if XML fails for you on a small file force non-slurping mode with
 
     $foo = MyPackageName::Database::Foo->new({
         directory => '/var/db',
-        max_slurp_size => 1	# force to not use slurp and therefore to use SQL
+        max_slurp_size => 0	# force to not use slurp and therefore to use SQL
     });
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015-2024 Nigel Horne.
+Copyright 2015-2025 Nigel Horne.
 
 This program is released under the following licence: GPL2.
 Usage is subject to licence terms.
